pub struct TabsPageProps {
pub title: String,
pub icon: Option<String>,
}Expand description
One tab’s content container. title is its tab label (read by the host on insert);
icon is its optional bundled-image name, set on the tab item where the backend shows
tab icons (iOS UITabBarItem), ignored otherwise.
Fields
title: Stringicon: Option<String>Trait Implementations
Sourceimpl Clone for TabsPageProps
impl Clone for TabsPageProps
Sourcefn clone(&self) -> TabsPageProps
fn clone(&self) -> TabsPageProps
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TabsPageProps
impl Debug for TabsPageProps
Sourceimpl Default for TabsPageProps
impl Default for TabsPageProps
Sourcefn default() -> TabsPageProps
fn default() -> TabsPageProps
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for TabsPageProps
impl PartialEq for TabsPageProps
Sourcefn eq(&self, other: &TabsPageProps) -> bool
fn eq(&self, other: &TabsPageProps) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TabsPageProps